@@ -125,7 +125,9 @@ sub test_001 : Tags(job_stats) {
 
     my @files = glob( $test->outdir . "/*" );
 
-    is( scalar @files, 18, "Got the right number of files" );
+    is( scalar @files, 8, "Got the right number of files" );
+
+    # diag Dumper(\@files);
 
     #We have 6 different batches spread over 3 arrays
     #Each batch corresponds to max_array_size
@@ -133,18 +135,27 @@ sub test_001 : Tags(job_stats) {
     #batch 0-1 are array 1
     #batch 2-3 are array 2
     #batch 4-5 are array 3
-    is_deeply( $test->jobs->{'blastx_scratch'}->batches->[0]->array_deps,
-        [ [ '1237_7', '1234_1' ] ] );
-    is_deeply( $test->jobs->{'blastx_scratch'}->batches->[1]->array_deps,
-        [ [ '1237_8', '1234_2' ] ] );
-    is_deeply( $test->jobs->{'blastx_scratch'}->batches->[2]->array_deps,
-        [ [ '1238_9', '1235_3' ] ] );
-    is_deeply( $test->jobs->{'blastx_scratch'}->batches->[3]->array_deps,
-        [ [ '1238_10', '1235_4' ] ] );
-    is_deeply( $test->jobs->{'blastx_scratch'}->batches->[4]->array_deps,
-        [ [ '1239_11', '1236_5' ] ] );
-    is_deeply( $test->jobs->{'blastx_scratch'}->batches->[5]->array_deps,
-        [ [ '1239_12', '1236_6' ] ] );
+    # is_deeply( $test->jobs->{'blastx_scratch'}->batches->[0]->array_deps,
+    #     [ [ '1237_7', '1234_1' ] ] );
+    # is_deeply( $test->jobs->{'blastx_scratch'}->batches->[1]->array_deps,
+    #     [ [ '1237_8', '1234_2' ] ] );
+    # is_deeply( $test->jobs->{'blastx_scratch'}->batches->[2]->array_deps,
+    #     [ [ '1238_9', '1235_3' ] ] );
+    # is_deeply( $test->jobs->{'blastx_scratch'}->batches->[3]->array_deps,
+    #     [ [ '1238_10', '1235_4' ] ] );
+    # is_deeply( $test->jobs->{'blastx_scratch'}->batches->[4]->array_deps,
+    #     [ [ '1239_11', '1236_5' ] ] );
+    # is_deeply( $test->jobs->{'blastx_scratch'}->batches->[5]->array_deps,
+    #     [ [ '1239_12', '1236_6' ] ] );
+    my $array_deps = [
+        [ '1237_7',  '1236_1' ],
+        [ '1237_8',  '1236_2' ],
+        [ '1238_9',  '1236_3' ],
+        [ '1238_10', '1236_4' ],
+        [ '1239_11', '1236_5' ],
+        [ '1239_12', '1236_6' ]
+    ];
+    is_deeply($test->array_deps, $array_deps);
 
     is_deeply(
         $test->jobs->{'blastx_scratch'}->batch_indexes->[0],
